@@ -10,6 +10,7 @@ from apscheduler.executors.asyncio import AsyncIOExecutor
 from apscheduler.triggers.interval import IntervalTrigger
 from pydantic import BaseModel
 from sanic import json, Sanic, Request
+from sanic.models.protocol_types import Range
 from sanic_ext.config import add_fallback_config
 from sanic_ext.extensions.openapi.blueprint import blueprint_factory
 from sanic_ext.extensions.openapi.builders import SpecificationBuilder
@@ -44,6 +45,7 @@ from web_foundation.resources.resource import Resource
 from web_foundation.resources.stores.memory_dict import InMemoryDictStore
 from web_foundation.settings_event import SettingsChangeEvent
 from web_foundation.utils.helpers import load_config
+from sanic.response import file_stream
 
 
 class AnyModel(AbstractDbModel):
@@ -87,14 +89,18 @@ if __name__ == '__main__':
     dispatcher = IDispatcher(scheduler=scheduler)
     app = App(dependency_container=container, dispatcher=dispatcher)
 
+
     # app.sanic.config.HEALTH = True
     # app.sanic.config.HEALTH_ENDPOINT = True
     async def check_add(s_app, *args, **kwargs):
         add_loader: TestAddonLoader = s_app.ctx.container.addon_loader()
         pl = await add_loader.find_addon_by_name("lskdjflkjsdlfkjsdlkfjlsdfj")
         loguru.logger.warning(f"on {os.getpid()} plugin {pl}")
+
+
     app.sanic.before_server_stop(check_add)
 
+
 class TestEvent(IMessage):
     message_type = "test_event"
     exec_inner = True
@@ -165,6 +171,31 @@ async def emmit_sse_event(ctx, container):
     return json({"ok": "ok"})
 
 
+class MyRange(Range):
+    @property
+    def start(self) -> int:
+        return 1024
+
+    @property
+    def size(self) -> int:
+        return 1024
+
+    @property
+    def end(self) -> int:
+        return 1024
+
+    @property
+    def total(self) -> int:
+        return 1024
+
+
+async def give_file(ctx, container):
+    return await file_stream(
+        location="test.json",
+        chunk_size=1024,
+        _range=MyRange())
+
+
 if __name__ == '__main__':
     routes_dict = {
         "apps": [
@@ -202,11 +233,17 @@ if __name__ == '__main__':
                             }
                         }
                     },
+                    "/test_file": {
+                        "v1": {
+                            "get": {"handler": give_file,
+                                    "protector": None, },
+                        }
+                    },
                 }
             }
         ]
     }
-    router = DictRouter(routes_dict, ChainRequestHandler, open_api=True)
+    router = DictRouter[ChainRequestHandler](routes_dict, ChainRequestHandler, open_api=True)
     app.add_custom_router(router)
 
     if "generate_openapi" in sys.argv:
