@@ -6,6 +6,7 @@ from typing import Dict
 
 from pydantic import BaseModel as PdModel
 from sanic import Request, json, HTTPResponse
+from sanic.response import ResponseStream
 
 from web_foundation.kernel.container import GenericDependencyContainer
 from web_foundation.extentions.addons.addon_loader import AddonsLoader
@@ -92,7 +93,7 @@ class ChainRequestHandler(ExtRequestHandler):
                         await plugin.exec_after(context=incoming, container=self.container, target_result=ret_val)
             else:
                 ret_val = await target(incoming, self.container)
-            if isinstance(ret_val, HTTPResponse):
+            if isinstance(ret_val, HTTPResponse) or isinstance(ret_val, ResponseStream):
                 return ret_val
             return self.response_fabric(ret_val)
 
