@@ -7,6 +7,7 @@ from typing import Callable, Type
 import sanic_ext
 from sanic_ext.extensions.openapi.types import Schema, Array
 from tortoise import Model
+from web_foundation import settings
 
 
 def set_access_endpoints(access_endpoints: dict, models,
@@ -69,6 +70,8 @@ def set_access_endpoints(access_endpoints: dict, models,
                 method_protector = method_protector if method_protector else endpoint_protector
                 if param.get('out_dto'):
                     out_struct = param.get('out_dto')
+                elif not hasattr(settings, "OPENAPI") or not getattr(settings, "OPENAPI"):
+                    out_struct = None
                 else:
                     # get out_struct from model name (in exec_access args)
                     func_text = inspect.getsource(target_func)
